srsgui.task package
===================

srsgui.task.task module
-----------------------

.. autoclass:: srsgui.task.task.Task
   :members:
   :no-undoc-members: EscapeForResult, EscapeForDevice, EscapeForStatus, EscapeForStart, EscapeForStop
   :show-inheritance:

srsgui.task.callbacks module
----------------------------

.. automodule:: srsgui.task.callbacks
   :members:
   :undoc-members:
   :show-inheritance:

srsgui.task.inputs module
-------------------------

.. automodule:: srsgui.task.inputs
   :members:
   :undoc-members:
   :show-inheritance:

srsgui.task.config module
-------------------------

.. automodule:: srsgui.task.config
   :members:
   :undoc-members:
   :show-inheritance:

srsgui.task.sessionhandler module
---------------------------------

.. automodule:: srsgui.task.sessionhandler
   :members:
   :undoc-members:
   :show-inheritance:

srsgui.task.taskresult module
-----------------------------

.. automodule:: srsgui.task.taskresult
   :members:
   :undoc-members:
   :show-inheritance:

